import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface ERC721Interface extends utils.Interface {
    functions: {
        "name()": FunctionFragment;
        "kittyIndexToApproved(uint256)": FunctionFragment;
        "partIndexToApproved(uint256)": FunctionFragment;
        "allowed(address,uint256)": FunctionFragment;
        "getApproved(uint256)": FunctionFragment;
        "approve(address,uint256)": FunctionFragment;
        "totalSupply()": FunctionFragment;
        "transfer(address,uint256)": FunctionFragment;
        "transferFrom(address,address,uint256)": FunctionFragment;
        "tokenOfOwnerByIndex(address,uint256)": FunctionFragment;
        "safeTransferFrom(address,address,uint256)": FunctionFragment;
        "safeTransferFrom(address,address,uint256,bytes)": FunctionFragment;
        "exists(uint256)": FunctionFragment;
        "tokenByIndex(uint256)": FunctionFragment;
        "ownerOf(uint256)": FunctionFragment;
        "balanceOf(address)": FunctionFragment;
        "symbol()": FunctionFragment;
        "setApprovalForAll(address,bool)": FunctionFragment;
        "tokenURI(uint256)": FunctionFragment;
        "isApprovedForAll(address,address)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "name" | "kittyIndexToApproved" | "partIndexToApproved" | "allowed" | "getApproved" | "approve" | "totalSupply" | "transfer" | "transferFrom" | "tokenOfOwnerByIndex" | "safeTransferFrom(address,address,uint256)" | "safeTransferFrom(address,address,uint256,bytes)" | "exists" | "tokenByIndex" | "ownerOf" | "balanceOf" | "symbol" | "setApprovalForAll" | "tokenURI" | "isApprovedForAll"): FunctionFragment;
    encodeFunctionData(functionFragment: "name", values?: undefined): string;
    encodeFunctionData(functionFragment: "kittyIndexToApproved", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "partIndexToApproved", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "allowed", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getApproved", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "approve", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "transfer", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferFrom", values: [string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "tokenOfOwnerByIndex", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "safeTransferFrom(address,address,uint256)", values: [string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "safeTransferFrom(address,address,uint256,bytes)", values: [string, string, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "exists", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "tokenByIndex", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "ownerOf", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [string]): string;
    encodeFunctionData(functionFragment: "symbol", values?: undefined): string;
    encodeFunctionData(functionFragment: "setApprovalForAll", values: [string, boolean]): string;
    encodeFunctionData(functionFragment: "tokenURI", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "isApprovedForAll", values: [string, string]): string;
    decodeFunctionResult(functionFragment: "name", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "kittyIndexToApproved", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "partIndexToApproved", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "allowed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getApproved", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "approve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferFrom", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokenOfOwnerByIndex", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "safeTransferFrom(address,address,uint256)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "safeTransferFrom(address,address,uint256,bytes)", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exists", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokenByIndex", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "ownerOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "symbol", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setApprovalForAll", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokenURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isApprovedForAll", data: BytesLike): Result;
    events: {
        "Transfer(address,address,uint256)": EventFragment;
        "Approval(address,address,uint256)": EventFragment;
        "ApprovalForAll(address,address,bool)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Transfer"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Approval"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ApprovalForAll"): EventFragment;
}
export interface TransferEventObject {
    _from: string;
    _to: string;
    _tokenId: BigNumber;
}
export type TransferEvent = TypedEvent<[
    string,
    string,
    BigNumber
], TransferEventObject>;
export type TransferEventFilter = TypedEventFilter<TransferEvent>;
export interface ApprovalEventObject {
    _owner: string;
    _approved: string;
    _tokenId: BigNumber;
}
export type ApprovalEvent = TypedEvent<[
    string,
    string,
    BigNumber
], ApprovalEventObject>;
export type ApprovalEventFilter = TypedEventFilter<ApprovalEvent>;
export interface ApprovalForAllEventObject {
    _owner: string;
    _operator: string;
    _approved: boolean;
}
export type ApprovalForAllEvent = TypedEvent<[
    string,
    string,
    boolean
], ApprovalForAllEventObject>;
export type ApprovalForAllEventFilter = TypedEventFilter<ApprovalForAllEvent>;
export interface ERC721 extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ERC721Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        name(overrides?: CallOverrides): Promise<[string]>;
        kittyIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        partIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        allowed(arg0: string, arg1: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        getApproved(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        approve(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        totalSupply(overrides?: CallOverrides): Promise<[BigNumber]>;
        transfer(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        transferFrom(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        tokenOfOwnerByIndex(_owner: string, _index: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        "safeTransferFrom(address,address,uint256)"(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        "safeTransferFrom(address,address,uint256,bytes)"(_from: string, _to: string, _tokenId: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        exists(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<[boolean]>;
        tokenByIndex(_index: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        ownerOf(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        balanceOf(_owner: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        symbol(overrides?: CallOverrides): Promise<[string]>;
        setApprovalForAll(_to: string, _approved: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<ContractTransaction>;
        tokenURI(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        isApprovedForAll(_owner: string, _operator: string, overrides?: CallOverrides): Promise<[boolean]>;
    };
    name(overrides?: CallOverrides): Promise<string>;
    kittyIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
    partIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
    allowed(arg0: string, arg1: BigNumberish, overrides?: CallOverrides): Promise<string>;
    getApproved(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
    approve(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    totalSupply(overrides?: CallOverrides): Promise<BigNumber>;
    transfer(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    transferFrom(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    tokenOfOwnerByIndex(_owner: string, _index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    "safeTransferFrom(address,address,uint256)"(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    "safeTransferFrom(address,address,uint256,bytes)"(_from: string, _to: string, _tokenId: BigNumberish, _data: BytesLike, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    exists(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    tokenByIndex(_index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    ownerOf(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
    balanceOf(_owner: string, overrides?: CallOverrides): Promise<BigNumber>;
    symbol(overrides?: CallOverrides): Promise<string>;
    setApprovalForAll(_to: string, _approved: boolean, overrides?: Overrides & {
        from?: string;
    }): Promise<ContractTransaction>;
    tokenURI(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
    isApprovedForAll(_owner: string, _operator: string, overrides?: CallOverrides): Promise<boolean>;
    callStatic: {
        name(overrides?: CallOverrides): Promise<string>;
        kittyIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
        partIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<string>;
        allowed(arg0: string, arg1: BigNumberish, overrides?: CallOverrides): Promise<string>;
        getApproved(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
        approve(_to: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        totalSupply(overrides?: CallOverrides): Promise<BigNumber>;
        transfer(_to: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        transferFrom(_from: string, _to: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        tokenOfOwnerByIndex(_owner: string, _index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        "safeTransferFrom(address,address,uint256)"(_from: string, _to: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        "safeTransferFrom(address,address,uint256,bytes)"(_from: string, _to: string, _tokenId: BigNumberish, _data: BytesLike, overrides?: CallOverrides): Promise<void>;
        exists(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        tokenByIndex(_index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        ownerOf(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
        balanceOf(_owner: string, overrides?: CallOverrides): Promise<BigNumber>;
        symbol(overrides?: CallOverrides): Promise<string>;
        setApprovalForAll(_to: string, _approved: boolean, overrides?: CallOverrides): Promise<void>;
        tokenURI(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
        isApprovedForAll(_owner: string, _operator: string, overrides?: CallOverrides): Promise<boolean>;
    };
    filters: {
        "Transfer(address,address,uint256)"(_from?: string | null, _to?: string | null, _tokenId?: null): TransferEventFilter;
        Transfer(_from?: string | null, _to?: string | null, _tokenId?: null): TransferEventFilter;
        "Approval(address,address,uint256)"(_owner?: string | null, _approved?: string | null, _tokenId?: null): ApprovalEventFilter;
        Approval(_owner?: string | null, _approved?: string | null, _tokenId?: null): ApprovalEventFilter;
        "ApprovalForAll(address,address,bool)"(_owner?: string | null, _operator?: string | null, _approved?: null): ApprovalForAllEventFilter;
        ApprovalForAll(_owner?: string | null, _operator?: string | null, _approved?: null): ApprovalForAllEventFilter;
    };
    estimateGas: {
        name(overrides?: CallOverrides): Promise<BigNumber>;
        kittyIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        partIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        allowed(arg0: string, arg1: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getApproved(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        approve(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        totalSupply(overrides?: CallOverrides): Promise<BigNumber>;
        transfer(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        transferFrom(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        tokenOfOwnerByIndex(_owner: string, _index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        "safeTransferFrom(address,address,uint256)"(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        "safeTransferFrom(address,address,uint256,bytes)"(_from: string, _to: string, _tokenId: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        exists(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        tokenByIndex(_index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        ownerOf(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        balanceOf(_owner: string, overrides?: CallOverrides): Promise<BigNumber>;
        symbol(overrides?: CallOverrides): Promise<BigNumber>;
        setApprovalForAll(_to: string, _approved: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<BigNumber>;
        tokenURI(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        isApprovedForAll(_owner: string, _operator: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        name(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        kittyIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        partIndexToApproved(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        allowed(arg0: string, arg1: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getApproved(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        approve(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        totalSupply(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transfer(_to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        transferFrom(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        tokenOfOwnerByIndex(_owner: string, _index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        "safeTransferFrom(address,address,uint256)"(_from: string, _to: string, _tokenId: BigNumberish, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        "safeTransferFrom(address,address,uint256,bytes)"(_from: string, _to: string, _tokenId: BigNumberish, _data: BytesLike, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        exists(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tokenByIndex(_index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        ownerOf(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        balanceOf(_owner: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        symbol(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setApprovalForAll(_to: string, _approved: boolean, overrides?: Overrides & {
            from?: string;
        }): Promise<PopulatedTransaction>;
        tokenURI(_tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isApprovedForAll(_owner: string, _operator: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
